Module replicate_datastore

Module replicate_datastore 

Traits

Datastore
Datastores may choose to make it possible to have all syncs / schools syncs /term syncs work with each other, but they may also choose to make some of them mutaully exclusive

Functions

get_datastore
gets the datastore that is selected as per the first feature