pub struct ClassDataSync {
pub table_name: TableName,
pub sync_action: SyncAction,
pub pk_fields: HashMap<String, Value>,
pub relevant_fields: Option<HashMap<String, Value>>,
}Fields
table_name: TableNamesync_action: SyncActionpk_fields: HashMap<String, Value>column names are not sanitized by default so it is recommended to use the verify_columns method
when using column names in sql expressions
relevant_fields: Option<HashMap<String, Value>>column names are not sanitized by default so it is recommended to use the verify_columns method
when using column names in sql expressions
Implementations
Sourceimpl ClassDataSync
impl ClassDataSync
Sourcepub fn verify_columns(&self) -> Result<(), Error>
pub fn verify_columns(&self) -> Result<(), Error>
This funciton should be used to verify columns in case of sql injection